@@ -953,12 +953,21 @@ def constTable():
     thing = tabulate(conlist, headers = headers)
     print(thing)
 
-def graph(*args, lrange=-10, urange=10, graph_points=100, graph_title=None):
+def graph(*args, lrangex=-10, urangex=10, lrangey=-10, urangey=10, graph_points=100, gridset=True, scaling=True, graph_title=None, xtitle=None, ytitle=None):
     i = 0
+    x = np.linspace(lrangex, urangex, graph_points)
     while i < len(args):
-        x = np.linspace(lrange, urange, graph_points)
-        y = evaluateExpression(args[i])
-        plt.title(graph_title)
+        if type(eval(args[i])) == np.ndarray:
+            y = eval(args[i])
+        else:
+            pass
         plt.plot(x,y)
         i+=1
+    plt.title(graph_title)
+    plt.xlabel(xtitle,fontsize=20)
+    plt.ylabel(ytitle,fontsize=20)
+    plt.autoscale(enable=scaling)
+    plt.grid(gridset)
+    plt.xlim([lrangex,urangex])
+    plt.ylim([lrangey,urangey])
     plt.show()
